Class: RuboCop::Cop::Sorbet::HasSigil

Inherits:
ValidSigil
  • Object
show all
Defined in:
lib/rubocop/cop/sorbet/sigils/has_sigil.rb

Overview

Makes the Sorbet typed sigil mandatory in all files.

Options:

  • SuggestedStrictness: Sorbet strictness level suggested in offense messages (default: 'false')
  • MinimumStrictness: If set, make offense if the strictness level in the file is below this one

If a SuggestedStrictness level is specified, it will be used in autocorrect. If a MinimumStrictness level is specified, it will be used in offense messages and autocorrect.

Instance Method Summary collapse

Methods inherited from ValidSigil

#on_new_investigation

Instance Method Details

#require_sigil_on_all_files?Boolean

Returns:

  • (Boolean)


19
20
21
# File 'lib/rubocop/cop/sorbet/sigils/has_sigil.rb', line 19

def require_sigil_on_all_files?
  true
end