Class: RuboCop::Cop::Sorbet::StrictSigil

Inherits:
HasSigil show all
Defined in:
lib/rubocop/cop/sorbet/sigils/strict_sigil.rb

Overview

Makes the Sorbet strict sigil mandatory in all files.

Examples:


# bad
# typed: true

# bad
# typed: false

# good
# typed: strict

Cop Safety Information:

  • This cop is unsafe because Sorbet sigils may not exist yet when it is run.

Instance Method Summary collapse

Methods inherited from HasSigil

#require_sigil_on_all_files?

Methods inherited from ValidSigil

#on_new_investigation

Instance Method Details

#minimum_strictnessObject



26
27
28
# File 'lib/rubocop/cop/sorbet/sigils/strict_sigil.rb', line 26

def minimum_strictness
  "strict"
end