Module: RuboCop::Cop::Sorbet::RBSAssertionCorrection
- Includes:
- RangeHelp
- Included in:
- ForbidTAbsurd, ForbidTBind, ForbidTCast, ForbidTLet, ForbidTMust, ForbidTUnsafe
- Defined in:
- lib/rubocop/cop/sorbet/mixin/rbs_assertion_correction.rb
Overview
Shared guards for replacing Sorbet runtime assertions with RBS inline comments without changing the surrounding Ruby syntax.
Constant Summary collapse
- COMMENT_START =
"#"- NEWLINES =
["\n", "\r"].freeze